@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,10 +34,9 @@ from google.cloud.recommender_v1beta1.services.recommender import pagers
 from google.cloud.recommender_v1beta1.types import insight
 from google.cloud.recommender_v1beta1.types import recommendation
 from google.cloud.recommender_v1beta1.types import recommender_service
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import struct_pb2 as struct  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import RecommenderTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import RecommenderGrpcTransport
 from .transports.grpc_asyncio import RecommenderGrpcAsyncIOTransport
@@ -58,7 +55,7 @@ class RecommenderClientMeta(type):
     _transport_registry["grpc_asyncio"] = RecommenderGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[RecommenderTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -86,7 +83,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -118,10 +116,27 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            RecommenderClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -130,7 +145,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            RecommenderClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -140,10 +155,11 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @property
     def transport(self) -> RecommenderTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            RecommenderTransport: The transport used by the client instance.
+            RecommenderTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -151,7 +167,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
     def insight_path(
         project: str, location: str, insight_type: str, insight: str,
     ) -> str:
-        """Return a fully-qualified insight string."""
+        """Returns a fully-qualified insight string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}/insights/{insight}".format(
             project=project,
             location=location,
@@ -161,7 +177,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def parse_insight_path(path: str) -> Dict[str, str]:
-        """Parse a insight path into its component segments."""
+        """Parses a insight path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/insightTypes/(?P<insight_type>.+?)/insights/(?P<insight>.+?)$",
             path,
@@ -170,14 +186,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def insight_type_path(project: str, location: str, insight_type: str,) -> str:
-        """Return a fully-qualified insight_type string."""
+        """Returns a fully-qualified insight_type string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}".format(
             project=project, location=location, insight_type=insight_type,
         )
 
     @staticmethod
     def parse_insight_type_path(path: str) -> Dict[str, str]:
-        """Parse a insight_type path into its component segments."""
+        """Parses a insight_type path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/insightTypes/(?P<insight_type>.+?)$",
             path,
@@ -188,7 +204,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
     def recommendation_path(
         project: str, location: str, recommender: str, recommendation: str,
     ) -> str:
-        """Return a fully-qualified recommendation string."""
+        """Returns a fully-qualified recommendation string."""
         return "projects/{project}/locations/{location}/recommenders/{recommender}/recommendations/{recommendation}".format(
             project=project,
             location=location,
@@ -198,7 +214,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def parse_recommendation_path(path: str) -> Dict[str, str]:
-        """Parse a recommendation path into its component segments."""
+        """Parses a recommendation path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/recommenders/(?P<recommender>.+?)/recommendations/(?P<recommendation>.+?)$",
             path,
@@ -207,14 +223,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def recommender_path(project: str, location: str, recommender: str,) -> str:
-        """Return a fully-qualified recommender string."""
+        """Returns a fully-qualified recommender string."""
         return "projects/{project}/locations/{location}/recommenders/{recommender}".format(
             project=project, location=location, recommender=recommender,
         )
 
     @staticmethod
     def parse_recommender_path(path: str) -> Dict[str, str]:
-        """Parse a recommender path into its component segments."""
+        """Parses a recommender path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/recommenders/(?P<recommender>.+?)$",
             path,
@@ -223,7 +239,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -236,7 +252,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -247,7 +263,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -258,7 +274,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -269,7 +285,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -283,12 +299,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RecommenderTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the recommender client.
+        """Instantiates the recommender client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -296,10 +312,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.RecommenderTransport]): The
+            transport (Union[str, RecommenderTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -335,21 +351,18 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -361,12 +374,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -381,8 +396,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -392,7 +407,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -411,10 +426,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         type.
 
         Args:
-            request (:class:`~.recommender_service.ListInsightsRequest`):
+            request (google.cloud.recommender_v1beta1.types.ListInsightsRequest):
                 The request object. Request for the `ListInsights`
                 method.
-            parent (:class:`str`):
+            parent (str):
                 Required. The container resource on which to execute the
                 request. Acceptable formats:
 
@@ -426,10 +441,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 https://cloud.google.com/about/locations/
                 INSIGHT_TYPE_ID refers to supported insight types:
                 https://cloud.google.com/recommender/docs/insights/insight-types.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -437,8 +452,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListInsightsPager:
-                Response to the ``ListInsights`` method.
+            google.cloud.recommender_v1beta1.services.recommender.pagers.ListInsightsPager:
+                Response to the ListInsights method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -460,10 +475,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.ListInsightsRequest):
             request = recommender_service.ListInsightsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -502,14 +515,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         permission for the specified insight type.
 
         Args:
-            request (:class:`~.recommender_service.GetInsightRequest`):
+            request (google.cloud.recommender_v1beta1.types.GetInsightRequest):
                 The request object. Request to the `GetInsight` method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the insight.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -517,7 +529,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.insight.Insight:
+            google.cloud.recommender_v1beta1.types.Insight:
                 An insight along with the information
                 used to derive the insight. The insight
                 may have associated recomendations as
@@ -540,10 +552,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.GetInsightRequest):
             request = recommender_service.GetInsightRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -586,27 +596,28 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         specified insight.
 
         Args:
-            request (:class:`~.recommender_service.MarkInsightAcceptedRequest`):
+            request (google.cloud.recommender_v1beta1.types.MarkInsightAcceptedRequest):
                 The request object. Request for the
                 `MarkInsightAccepted` method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the insight.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (:class:`Sequence[~.recommender_service.MarkInsightAcceptedRequest.StateMetadataEntry]`):
+            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkInsightAcceptedRequest.StateMetadataEntry]):
                 Optional. State properties user wish to include with
                 this state. Full replace of the current state_metadata.
+
                 This corresponds to the ``state_metadata`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            etag (:class:`str`):
+            etag (str):
                 Required. Fingerprint of the Insight.
                 Provides optimistic locking.
+
                 This corresponds to the ``etag`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -614,7 +625,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.insight.Insight:
+            google.cloud.recommender_v1beta1.types.Insight:
                 An insight along with the information
                 used to derive the insight. The insight
                 may have associated recomendations as
@@ -637,18 +648,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.MarkInsightAcceptedRequest):
             request = recommender_service.MarkInsightAcceptedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
+            if state_metadata is not None:
+                request.state_metadata = state_metadata
             if etag is not None:
                 request.etag = etag
 
-            if state_metadata:
-                request.state_metadata.update(state_metadata)
-
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.mark_insight_accepted]
@@ -679,10 +687,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.list IAM permission for the specified recommender.
 
         Args:
-            request (:class:`~.recommender_service.ListRecommendationsRequest`):
+            request (google.cloud.recommender_v1beta1.types.ListRecommendationsRequest):
                 The request object. Request for the
                 `ListRecommendations` method.
-            parent (:class:`str`):
+            parent (str):
                 Required. The container resource on which to execute the
                 request. Acceptable formats:
 
@@ -694,18 +702,19 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 https://cloud.google.com/about/locations/ RECOMMENDER_ID
                 refers to supported recommenders:
                 https://cloud.google.com/recommender/docs/recommenders.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            filter (:class:`str`):
+            filter (str):
                 Filter expression to restrict the recommendations
                 returned. Supported filter fields: state_info.state Eg:
                 \`state_info.state:"DISMISSED" or
-                state_info.state:"FAILED".
+                state_info.state:"FAILED"
+
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -713,8 +722,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListRecommendationsPager:
-                Response to the ``ListRecommendations`` method.
+            google.cloud.recommender_v1beta1.services.recommender.pagers.ListRecommendationsPager:
+                Response to the ListRecommendations method.
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -736,10 +745,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.ListRecommendationsRequest):
             request = recommender_service.ListRecommendationsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if filter is not None:
@@ -780,15 +787,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.get IAM permission for the specified recommender.
 
         Args:
-            request (:class:`~.recommender_service.GetRecommendationRequest`):
+            request (google.cloud.recommender_v1beta1.types.GetRecommendationRequest):
                 The request object. Request to the `GetRecommendation`
                 method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the recommendation.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -796,7 +802,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.recommendation.Recommendation:
+            google.cloud.recommender_v1beta1.types.Recommendation:
                 A recommendation along with a
                 suggested action. E.g., a rightsizing
                 recommendation for an underutilized VM,
@@ -819,10 +825,8 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.GetRecommendationRequest):
             request = recommender_service.GetRecommendationRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -868,30 +872,31 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         specified recommender.
 
         Args:
-            request (:class:`~.recommender_service.MarkRecommendationClaimedRequest`):
+            request (google.cloud.recommender_v1beta1.types.MarkRecommendationClaimedRequest):
                 The request object. Request for the
                 `MarkRecommendationClaimed` Method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the recommendation.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (:class:`Sequence[~.recommender_service.MarkRecommendationClaimedRequest.StateMetadataEntry]`):
+            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match
                 the regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+
                 This corresponds to the ``state_metadata`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            etag (:class:`str`):
+            etag (str):
                 Required. Fingerprint of the
                 Recommendation. Provides optimistic
                 locking.
+
                 This corresponds to the ``etag`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -899,7 +904,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.recommendation.Recommendation:
+            google.cloud.recommender_v1beta1.types.Recommendation:
                 A recommendation along with a
                 suggested action. E.g., a rightsizing
                 recommendation for an underutilized VM,
@@ -924,18 +929,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             request, recommender_service.MarkRecommendationClaimedRequest
         ):
             request = recommender_service.MarkRecommendationClaimedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
+            if state_metadata is not None:
+                request.state_metadata = state_metadata
             if etag is not None:
                 request.etag = etag
 
-            if state_metadata:
-                request.state_metadata.update(state_metadata)
-
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[
@@ -980,30 +982,31 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         specified recommender.
 
         Args:
-            request (:class:`~.recommender_service.MarkRecommendationSucceededRequest`):
+            request (google.cloud.recommender_v1beta1.types.MarkRecommendationSucceededRequest):
                 The request object. Request for the
                 `MarkRecommendationSucceeded` Method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the recommendation.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (:class:`Sequence[~.recommender_service.MarkRecommendationSucceededRequest.StateMetadataEntry]`):
+            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match
                 the regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+
                 This corresponds to the ``state_metadata`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            etag (:class:`str`):
+            etag (str):
                 Required. Fingerprint of the
                 Recommendation. Provides optimistic
                 locking.
+
                 This corresponds to the ``etag`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1011,7 +1014,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.recommendation.Recommendation:
+            google.cloud.recommender_v1beta1.types.Recommendation:
                 A recommendation along with a
                 suggested action. E.g., a rightsizing
                 recommendation for an underutilized VM,
@@ -1036,18 +1039,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
             request, recommender_service.MarkRecommendationSucceededRequest
         ):
             request = recommender_service.MarkRecommendationSucceededRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
+            if state_metadata is not None:
+                request.state_metadata = state_metadata
             if etag is not None:
                 request.etag = etag
 
-            if state_metadata:
-                request.state_metadata.update(state_metadata)
-
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[
@@ -1092,30 +1092,31 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         specified recommender.
 
         Args:
-            request (:class:`~.recommender_service.MarkRecommendationFailedRequest`):
+            request (google.cloud.recommender_v1beta1.types.MarkRecommendationFailedRequest):
                 The request object. Request for the
                 `MarkRecommendationFailed` Method.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the recommendation.
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (:class:`Sequence[~.recommender_service.MarkRecommendationFailedRequest.StateMetadataEntry]`):
+            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match
                 the regex ``/^[a-zA-Z0-9_./-]{0,255}$/``.
+
                 This corresponds to the ``state_metadata`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            etag (:class:`str`):
+            etag (str):
                 Required. Fingerprint of the
                 Recommendation. Provides optimistic
                 locking.
+
                 This corresponds to the ``etag`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1123,7 +1124,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.recommendation.Recommendation:
+            google.cloud.recommender_v1beta1.types.Recommendation:
                 A recommendation along with a
                 suggested action. E.g., a rightsizing
                 recommendation for an underutilized VM,
@@ -1146,18 +1147,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # there are no flattened fields.
         if not isinstance(request, recommender_service.MarkRecommendationFailedRequest):
             request = recommender_service.MarkRecommendationFailedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
+            if state_metadata is not None:
+                request.state_metadata = state_metadata
             if etag is not None:
                 request.etag = etag
 
-            if state_metadata:
-                request.state_metadata.update(state_metadata)
-
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[
